==> qtjambi-networkauth-debuginfo-windows-x64-5.15.17.jar: sources/QtJambiNetworkAuth/QOAuth2AuthorizationCodeFlow_shell.h <==
#ifndef QOAUTH2AUTHORIZATIONCODEFLOW_SHELL_H
#define QOAUTH2AUTHORIZATIONCODEFLOW_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtNetworkAuth/qoauth2authorizationcodeflow.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <qtnetwork-config.h>
#if QT_CONFIG(http)
#include <QtNetwork/qhttpmultipart.h>
#endif //QT_CONFIG(http)
#include <QtNetwork/qnetworkaccessmanager.h>
#include <QtNetwork/qnetworkreply.h>
#include <QtNetwork/qnetworkrequest.h>
#include <QtNetworkAuth/qabstractoauth.h>
#include <QtNetworkAuth/qabstractoauthreplyhandler.h>
#include <QtJambi/RegistryAPI>


class QOAuth2AuthorizationCodeFlow_shell : public QOAuth2AuthorizationCodeFlow, public QtJambiShellInterface
{
public:
    QOAuth2AuthorizationCodeFlow_shell(QNetworkAccessManager* manager0, QObject* parent1 = nullptr);
    QOAuth2AuthorizationCodeFlow_shell(QObject* parent0 = nullptr);
    QOAuth2AuthorizationCodeFlow_shell(const QString& clientIdentifier0, QNetworkAccessManager* manager1, QObject* parent2 = nullptr);
    QOAuth2AuthorizationCodeFlow_shell(const QString& clientIdentifier0, const QUrl& authorizationUrl1, const QUrl& accessTokenUrl2, QNetworkAccessManager* manager3, QObject* parent4 = nullptr);
    QOAuth2AuthorizationCodeFlow_shell(const QUrl& authorizationUrl0, const QUrl& accessTokenUrl1, QNetworkAccessManager* manager2, QObject* parent3 = nullptr);
    ~QOAuth2AuthorizationCodeFlow_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QUrl createAuthenticatedUrl(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void customEvent(QEvent* event0) override;
    QNetworkReply* deleteResource(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QNetworkReply* get(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void grant() override;
    QNetworkReply* head(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    QNetworkReply* post(const QUrl& url0, QHttpMultiPart* multiPart1) override;
    QNetworkReply* post(const QUrl& url0, const QByteArray& data1) override;
    QNetworkReply* post(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    QNetworkReply* put(const QUrl& url0, QHttpMultiPart* multiPart1) override;
    QNetworkReply* put(const QUrl& url0, const QByteArray& data1) override;
    QNetworkReply* put(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void resourceOwnerAuthorization(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QOAuth2AuthorizationCodeFlow_access : public QOAuth2AuthorizationCodeFlow
{
    jobject __qt_buildAuthenticateUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject parameters0);
    void __qt_requestAccessToken_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring code0);
    void __qt_grant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_resourceOwnerAuthorization_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
};

#endif // QOAUTH2AUTHORIZATIONCODEFLOW_SHELL_H

==> qtjambi-networkauth-debuginfo-windows-x64-6.5.3.jar: sources/QtJambiNetworkAuth/QOAuth2AuthorizationCodeFlow_shell.h <==
#ifndef QOAUTH2AUTHORIZATIONCODEFLOW_SHELL_H
#define QOAUTH2AUTHORIZATIONCODEFLOW_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtNetworkAuth/qoauth2authorizationcodeflow.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QMultiMap>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <qtnetwork-config.h>
#if QT_CONFIG(http)
#include <QtNetwork/qhttpmultipart.h>
#endif //QT_CONFIG(http)
#include <QtNetwork/qnetworkaccessmanager.h>
#include <QtNetwork/qnetworkreply.h>
#include <QtNetwork/qnetworkrequest.h>
#include <QtNetwork/qsslconfiguration.h>
#include <QtNetworkAuth/qabstractoauth.h>
#include <QtNetworkAuth/qabstractoauthreplyhandler.h>
#include <QtJambi/RegistryAPI>


class QOAuth2AuthorizationCodeFlow_shell : public QOAuth2AuthorizationCodeFlow, public QtJambiShellInterface
{
public:
    QOAuth2AuthorizationCodeFlow_shell(QNetworkAccessManager* manager0, QObject* parent1 = nullptr);
    QOAuth2AuthorizationCodeFlow_shell(QObject* parent0 = nullptr);
    QOAuth2AuthorizationCodeFlow_shell(const QString& clientIdentifier0, QNetworkAccessManager* manager1, QObject* parent2 = nullptr);
    QOAuth2AuthorizationCodeFlow_shell(const QString& clientIdentifier0, const QUrl& authorizationUrl1, const QUrl& accessTokenUrl2, QNetworkAccessManager* manager3, QObject* parent4 = nullptr);
    QOAuth2AuthorizationCodeFlow_shell(const QUrl& authorizationUrl0, const QUrl& accessTokenUrl1, QNetworkAccessManager* manager2, QObject* parent3 = nullptr);
    ~QOAuth2AuthorizationCodeFlow_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QUrl createAuthenticatedUrl(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void customEvent(QEvent* event0) override;
    QNetworkReply* deleteResource(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QNetworkReply* get(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void grant() override;
    QNetworkReply* head(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    QNetworkReply* post(const QUrl& url0, QHttpMultiPart* multiPart1) override;
    QNetworkReply* post(const QUrl& url0, const QByteArray& data1) override;
    QNetworkReply* post(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void prepareRequest(QNetworkRequest* request0, const QByteArray& verb1, const QByteArray& body2) override;
    QNetworkReply* put(const QUrl& url0, QHttpMultiPart* multiPart1) override;
    QNetworkReply* put(const QUrl& url0, const QByteArray& data1) override;
    QNetworkReply* put(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void resourceOwnerAuthorization(const QUrl& url0, const QMultiMap<QString, QVariant>& parameters1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QOAuth2AuthorizationCodeFlow_access : public QOAuth2AuthorizationCodeFlow
{
    jobject __qt_buildAuthenticateUrl_cref_QMultiMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject parameters0);
    void __qt_requestAccessToken_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring code0);
    void __qt_grant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_resourceOwnerAuthorization_cref_QUrl_cref_QMultiMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
};

#endif // QOAUTH2AUTHORIZATIONCODEFLOW_SHELL_H
